ifgen.plugins.struct_receiver package — docs

Skip to main content
`Ctrl`+`K`

# ifgen.plugins.struct_receiver package

## Module contents

A struct-receiver interface implementation.

ifgen.plugins.struct_receiver.cpp_struct_receiver(task: GenerateTask) → None

  C++ struct receiver generation.

ifgen.plugins.struct_receiver.get_receiver_struct_names(task: GenerateTask) → list[str]

  Get names of structs to create receiver entries for.

ifgen.plugins.struct_receiver.python_struct_receiver(task: GenerateTask) → None

  Python struct receiver generation.